"use strict";


window.onerror = function (errorMsg, url, lineNumber, column, errorObj) {
    alert('Error: ' + errorMsg + ' Script: ' + url + ' Line: ' + lineNumber
    + ' Column: ' + column + ' StackTrace: ' +  errorObj);
};


// parseUri 1.2.2
// (c) Steven Levithan <stevenlevithan.com>
// MIT License
/* !parseUri */
function parseUri(str) {
    var o   = {
        strictMode: false,
        key: ["source", "protocol", "authority", "userInfo", "user", "password", "host", "port", "relative", "path", "directory", "file", "query", "anchor"],
        q:   {
            name:   "queryKey",
            parser: /(?:^|&)([^&=]*)=?([^&]*)/g
        },
        parser: {
            strict: /^(?:([^:\/?#]+):)?(?:\/\/((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?))?((((?:[^?#\/]*\/)*)([^?#]*))(?:\?([^#]*))?(?:#(.*))?)/,
            loose:  /^(?:(?![^:@]+:[^:@\/]*@)([^:\/?#.]+):)?(?:\/\/)?((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?)(((\/(?:[^?#](?![^?#\/]*\.[^?#\/.]+(?:[?#]|$)))*\/?)?([^?#\/]*))(?:\?([^#]*))?(?:#(.*))?)/
        }
    },
    m   = o.parser[o.strictMode ? "strict" : "loose"].exec(str),
    uri = {},
    i   = 14;

    while (i--) uri[o.key[i]] = m[i] || "";

    uri[o.q.name] = {};
    uri[o.key[12]].replace(o.q.parser, function ($0, $1, $2) {
        if ($1) uri[o.q.name][$1] = $2;
    });

    return uri;
}


// Catch-all error handler for $.getJSON calls.
$.ajaxSetup({
    //"error": function () { alert("Error communicating with Server.");  }
});


function savingOn(showSaving)
{
    $("#savingIndicator").show(1000);
}


function savingOff(showSaving)
{
    $("#savingIndicator").hide(1000);
}


function sleep(milliseconds, callback) {
	setTimeout(function ()
		{ callback(); }, milliseconds);
}


function afterSleep() {
    savingOff();
}


function interpolate(v, inMin, inMax, outMin, outMax) {
    var inRange, outRange, out;
    inRange = inMax - inMin;
    outRange = outMax - outMin;
    out = ((v - inMin) / inRange) * outRange + outMin;
    return (out);
}


function addRenderConfig(duplicate) {
    var renderConfigName = prompt("Name of new RenderConfig?");

    if(renderConfigName == null) {return}

    // Check that one of this name does not exist already.
    if (renderConfigsObj.renderConfigs[renderConfigName] != null) {
        if (confirm('A RenderConfig named "' + renderConfigName + '" already exists. Overwrite it?') != true) {
            return;
        }
    }

     // Check name for length.
    if (renderConfigName.length > 63) {
        alert("The name has been clipped to 63 characters.");
        renderConfigName = renderConfigName.substring(0, 63);
    }

     // Check name for validity.
    if (renderConfigName.includes(".")) {
        alert("The name may not contain a '.'.");
        return;
    }

    renderConfigsObj.renderConfigs[renderConfigName] = {
        description: "",
        calName: "",
        colorSetupName: "",
        screen: "HDS Medium",
        rotationDegrees: "0",
//                    resolution: Number(resolutions[0]), Removed as there is no 'one size fits all'.
        bitDepth: "1",
        printQuality: 1,
        complexity: 1,
        copyCount: "1",
        HVD: false,
        overspeed: false
	}

    // Remake the RenderConfigs menu and switch to the new RenderConfig.
		makeRenderConfigSelector();
		$("#selRenderConfig").val(renderConfigName);
    makeSelectorsForRenderConfig(renderConfigName, duplicate);
    localStorage["renderConfigNameSelected"] = renderConfigName;
}


function removeRenderConfig() {
    var renderConfigName = $("#selRenderConfig").val();
    if (confirm('Remove RenderConfig named "' + renderConfigName + '"?')) {
        delete renderConfigsObj.renderConfigs[renderConfigName];
        localStorage["renderConfigNameSelected"] = undefined;
        currentRenderConfigName = null;
        makeRenderConfigSelector();
        makeSelectorsForRenderConfig($("#selRenderConfig").val(), false);
        saveRenderConfigs();
    }
}

// Set a selector to a specified value; if it does not exist in the selector, select the first entry. Don't include '#' in the selector name.
function setSelector(selectorName, value) {
	$("#"+selectorName).val(value);
	if($("#"+selectorName).val() == null) {
		// This might occur if the selector does not contain the value we are trying to set it to, or 'value' is unset.
		$("#"+selectorName).prop("selectedIndex", 0);
	}
	//$("#"+selectorName).selectmenu();
	//$("#"+selectorName).selectmenu("refresh");

	// Redisplay the selector if possible, showing our new selection.
	// This try/catch lets us use this function for non-jQueryUI selectors (i.e conventional ones).
	try {$("#"+selectorName).selectmenu("refresh");}
	catch(err) {}

	console.log("Just selected: " + selectorName + ", " + $("#"+selectorName).val());
}

// Hide optional tabs (pages) which are disabled.
function hideUnwantedTabs() {
    if(localStorage["showPrinterPage"] != "true") {$("#optPrinter").hide();}
    if(localStorage["showHPPage"] != "true") {$("#optHP").hide();}
    if(localStorage["showDuraFlexPage"] != "true") {$("#optDuraFlex").hide();}
    if(localStorage["showDuraLinkPage"] != "true") {$("#optDuraLink").hide();}
    if(localStorage["showTIFFPage"] != "true") {$("#optTIFF").hide();}
    if(localStorage["showManCalPage"] != "true") {$("#optManCal").hide();}
}